// lib/features/auth/presentation/bloc/auth_state.dart
part of 'auth_bloc.dart';

abstract class AuthState {}

class AuthInitial extends AuthState {}

class AuthLoading extends AuthState {}

class AuthSuccess extends AuthState {
  final String phoneNumber;
  //
  // CHANGE: Made timeStamp and timeDue required.
  //
  final String timeStamp;
  final String timeDue;

  AuthSuccess({
    required this.phoneNumber,
    required this.timeStamp,
    required this.timeDue,
  });
}

class AuthError extends AuthState {
  final String message;

  AuthError(this.message);
}

class OTPVerified extends AuthState {}